@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 10.2's 2.6.18 kernel.
+# This is a kernel build script for openSUSE 11.0's 2.6.25 kernel.
 #
 
 die () {
@@ -13,9 +13,9 @@ cd /usr/lib/rpm/ || die "Can't chdir to /usr/lib/rpm/ ."
 if ! grep -q ccs-kernel find-supplements.ksyms
 then
 	patch << "EOF" || die "Can't patch find-supplements.ksyms ."
---- find-supplements.ksyms	2008-04-16 14:18:13.000000000 +0900
-+++ find-supplements.ksyms	2008-04-16 14:19:06.000000000 +0900
-@@ -6,6 +6,7 @@
+--- find-supplements.ksyms	2008-05-22 10:02:00.000000000 +0900
++++ find-supplements.ksyms	2008-06-11 11:04:06.000000000 +0900
+@@ -7,6 +7,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
  		       # kernel-module.
@@ -60,46 +60,44 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.18.8-0.13.src.rpm ]
+if [ ! -r kernel-source-2.6.25.20-0.1.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/suse/suse/update/10.2/rpm/src/kernel-source-2.6.18.8-0.13.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.0/rpm/src/kernel-source-2.6.25.20-0.1.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-source-2.6.18.8-0.13.src.rpm || die "Can't install source package."
+rpm -ivh kernel-source-2.6.25.20-0.1.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.6-20090314.tar.gz ]
+if [ ! -r ccs-patch-1.6.6-20090401.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.6-20090314.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.6-20090401.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-default.spec	2008-10-17 00:22:46.000000000 +0900
-+++ kernel-default.spec	2008-10-18 14:36:07.000000000 +0900
-@@ -30,13 +30,13 @@
- %define build_um  %([ default != um ] ; echo $?)
- %define build_vanilla  %([ default != vanilla ] ; echo $?)
+--- kernel-default.spec	2008-10-22 23:21:23.000000000 +0900
++++ kernel-default.spec	2008-10-28 17:22:15.000000000 +0900
+@@ -47,10 +47,10 @@
+ %define build_nomodules 1
+ %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
- %ifarch ia64
- # arch/ia64/scripts/unwcheck.py
- BuildRequires:  python
- %endif
- Version:        2.6.18.8
--Release: 0.13
-+Release: 0.13_tomoyo_1.6.6
  Summary:        The Standard Kernel for both Uniprocessor and Multiprocessor Systems
+ Version:        2.6.25.20
+-Release: 0.1
++Release: 0.1_tomoyo_1.6.6
  License:        GPL v2 or later
  Group:          System/Kernel
-@@ -242,6 +242,10 @@
+ Url:            http://www.kernel.org/
+@@ -314,6 +314,11 @@
  %build
  source .rpm-defs
- cd linux-2.6.18
+ cd linux-2.6.25
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.6-20090314.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.18-suse-10.2.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.6-20090401.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.25-suse-11.0.diff
++# sed -i -e 's:-ccs::' -- Makefile
 +cat config.ccs >> .config
  cp .config .config.orig
  %if %{tolerate_unknown_new_config_options}
