@@ -3,9 +3,9 @@
  *
  * Implementation of the Domain-Based Mandatory Access Control.
  *
- * Copyright (C) 2005-2008  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.6.5   2008/11/11
+ * Version: 1.6.6   2009/02/02
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -913,12 +913,6 @@ static bool get_argv0(struct linux_binprm *bprm, struct ccs_page_buffer *tmp)
 #endif
 		/* Map. */
 		kaddr = kmap(page);
-		if (!kaddr) { /* Mapping failed. */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) && defined(CONFIG_MMU)
-			put_page(page);
-#endif
-			goto out;
-		}
 		/* Read. */
 		while (offset < PAGE_SIZE) {
 			const unsigned char c = kaddr[offset++];
@@ -1198,12 +1192,6 @@ static int check_environ(struct ccs_request_info *r)
 #endif
 		/* Map. */
 		kaddr = kmap(page);
-		if (!kaddr) { /* Mapping failed. */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) && defined(CONFIG_MMU)
-			put_page(page);
-#endif
-			goto out;
-		}
 		/* Read. */
 		while (argv_count && offset < PAGE_SIZE) {
 			if (!kaddr[offset++])
@@ -1252,7 +1240,9 @@ static int check_environ(struct ccs_request_info *r)
 		i++;
 		offset = 0;
 	}
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) && defined(CONFIG_MMU)
  out:
+#endif
 	if (r->mode != 3)
 		error = 0;
 	return error;
@@ -1485,10 +1475,11 @@ static int try_alt_exec(struct ccs_request_info *r,
 			 "pid=%d uid=%d gid=%d euid=%d egid=%d suid=%d "
 			 "sgid=%d fsuid=%d fsgid=%d state[0]=%u "
 			 "state[1]=%u state[2]=%u",
-			 (pid_t) sys_getpid(), task->uid, task->gid, task->euid,
-			 task->egid, task->suid, task->sgid, task->fsuid,
-			 task->fsgid, (u8) (tomoyo_flags >> 24),
-			 (u8) (tomoyo_flags >> 16), (u8) (tomoyo_flags >> 8));
+			 (pid_t) sys_getpid(), current_uid(), current_gid(),
+			 current_euid(), current_egid(), current_suid(),
+			 current_sgid(), current_fsuid(), current_fsgid(),
+			 (u8) (tomoyo_flags >> 24), (u8) (tomoyo_flags >> 16),
+			 (u8) (tomoyo_flags >> 8));
 		retval = copy_strings_kernel(1, &buffer, bprm);
 		if (retval < 0)
 			goto out;
